==> v1.3.16.zip: element-android/matrix-sdk-android/src/main/java/org/matrix/android/sdk/internal/session/contentscanner/tasks/DownloadEncryptedTask.kt <==
/*
 * Copyright 2021 The Matrix.org Foundation C.I.C.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.matrix.android.sdk.internal.session.contentscanner.tasks

import okhttp3.ResponseBody
import org.matrix.android.sdk.internal.crypto.attachments.ElementToDecrypt
import org.matrix.android.sdk.internal.network.executeRequest
import org.matrix.android.sdk.internal.session.contentscanner.ContentScannerApiProvider
import org.matrix.android.sdk.internal.session.contentscanner.ScanEncryptorUtils
import org.matrix.android.sdk.internal.task.Task
import javax.inject.Inject

internal interface DownloadEncryptedTask : Task<DownloadEncryptedTask.Params, ResponseBody> {
    data class Params(
            val publicServerKey: String?,
            val encryptedInfo: ElementToDecrypt,
            val mxcUrl: String
    )
}

internal class DefaultDownloadEncryptedTask @Inject constructor(
        private val contentScannerApiProvider: ContentScannerApiProvider
) : DownloadEncryptedTask {

    override suspend fun execute(params: DownloadEncryptedTask.Params): ResponseBody {
        val dlBody = ScanEncryptorUtils.getDownloadBodyAndEncryptIfNeeded(
                params.publicServerKey,
                params.mxcUrl,
                params.encryptedInfo
        )

        val api = contentScannerApiProvider.contentScannerApi ?: throw IllegalArgumentException()
        return executeRequest(null) {
            api.downloadEncrypted(dlBody)
        }
    }
}

==> v1.4.16.zip: element-android/matrix-sdk-android/src/main/java/org/matrix/android/sdk/internal/session/contentscanner/tasks/DownloadEncryptedTask.kt <==
/*
 * Copyright 2021 The Matrix.org Foundation C.I.C.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.matrix.android.sdk.internal.session.contentscanner.tasks

import okhttp3.ResponseBody
import org.matrix.android.sdk.api.session.crypto.attachments.ElementToDecrypt
import org.matrix.android.sdk.internal.network.executeRequest
import org.matrix.android.sdk.internal.session.contentscanner.ContentScannerApiProvider
import org.matrix.android.sdk.internal.session.contentscanner.ScanEncryptorUtils
import org.matrix.android.sdk.internal.task.Task
import javax.inject.Inject

internal interface DownloadEncryptedTask : Task<DownloadEncryptedTask.Params, ResponseBody> {
    data class Params(
            val publicServerKey: String?,
            val encryptedInfo: ElementToDecrypt,
            val mxcUrl: String
    )
}

internal class DefaultDownloadEncryptedTask @Inject constructor(
        private val contentScannerApiProvider: ContentScannerApiProvider
) : DownloadEncryptedTask {

    override suspend fun execute(params: DownloadEncryptedTask.Params): ResponseBody {
        val dlBody = ScanEncryptorUtils.getDownloadBodyAndEncryptIfNeeded(
                params.publicServerKey,
                params.mxcUrl,
                params.encryptedInfo
        )

        val api = contentScannerApiProvider.contentScannerApi ?: throw IllegalArgumentException()
        return executeRequest(null) {
            api.downloadEncrypted(dlBody)
        }
    }
}
